==> ws-v3.70.10-src.tar.gz: ws-v3.70-10/src/mac/WSDmacCodeConvert.cpp <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#include <xunicode.h>
#include <WScom.h>
#include <mac/WSDmacCodeConvert.h>
#include <WSDenv.h>

WSDcodeConvert* _code_convert_create_handler_(){
  return new WSDmacCodeConvert;
}

int WSDmacCodeConvert::codeConvert(char* str,int max,int codeto,const char* src,int len,int codefrom){
  return XUCodeConv(str,max,codeto,src,len,codefrom);
//printf("WSDmacCodeConvert::codeConvert() not supported..\n");
  return 0;
}
int WSDmacCodeConvert::getSystemLocale(){
extern int XUGetLocale();
  return XUGetLocale();
//printf("WSDmacCodeConvert::getSystemLocale() not supported..\n");
  return WS_EN_SJIS;
}
void WSDmacCodeConvert::initialize(){
  XUInit();
}
int WSDmacCodeConvert::utf8CharLen(const char* str,int max){
printf("WSDmacCodeConvert::utf8CharLen() not supported..\n");
  return XUutf8CharLen(str,max); 
}
int WSDmacCodeConvert::encode(WSCushort* str,int max,const char* src,int len,int code){
//printf("WSDmacCodeConvert::encode() not supported..\n");
  return XUEncode((XUChar*)str,max,src,len,code);
  return 0;
}
int WSDmacCodeConvert::decode(char* str,int max,const WSCushort* src,int len,int code){
  return XUDecode(str,max,(XUChar*)src,len,code);
  str[0] = 0;
//printf("WSDmacCodeConvert::decode() not supported..\n");
  return 0;
}

==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/src/mac/WSDmacCodeConvert.cpp <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#include <xunicode.h>
#include <WScom.h>
#include <mac/WSDmacCodeConvert.h>
#include <WSDenv.h>

WSDcodeConvert* _code_convert_create_handler_(){
  return new WSDmacCodeConvert;
}

int WSDmacCodeConvert::codeConvert(char* str,int max,int codeto,const char* src,int len,int codefrom){
  return XUCodeConv(str,max,codeto,src,len,codefrom);
//printf("WSDmacCodeConvert::codeConvert() not supported..\n");
  return 0;
}
int WSDmacCodeConvert::getSystemEncoding(){
extern int XUGetLocale();
  return XUGetLocale();
//printf("WSDmacCodeConvert::getSystemLocale() not supported..\n");
  return WS_EN_SJIS;
}
void WSDmacCodeConvert::initialize(){
  XUInit();
extern char* XUGetLang();
  setSystemLocaleName(XUGetLang(),getSystemEncoding());
}
int WSDmacCodeConvert::utf8CharLen(const char* str,int max){
printf("WSDmacCodeConvert::utf8CharLen() not supported..\n");
  return XUutf8CharLen(str,max); 
}
int WSDmacCodeConvert::encode(WSCushort* str,int max,const char* src,int len,int code){
//printf("WSDmacCodeConvert::encode() not supported..\n");
  return XUEncode((XUChar*)str,max,src,len,code);
  return 0;
}
int WSDmacCodeConvert::decode(char* str,int max,const WSCushort* src,int len,int code){
  return XUDecode(str,max,(XUChar*)src,len,code);
  str[0] = 0;
//printf("WSDmacCodeConvert::decode() not supported..\n");
  return 0;
}
